@@ -225,6 +225,9 @@ class Aphantasia(ImageGenerator):
     ):
         shift = None
 
+        height = latents.shape[2]
+        width = (latents.shape[3] - 1) * 2
+
         #NOTE: generat all possible freqs for the input image size
         img_freqs = self.compute_2d_img_freqs(
             height=height,
